@@ -89,6 +89,22 @@ def {link.name}(self, _: T.Optional[{link_resolver_name}] = None, /) -> {node_re
     """
 
 
+def build_get_functions_str(node_name: str, exclusive_field_names: T.Set[str]) -> str:
+    params_fields_str = ", ".join(
+        [f"{f}: T.Optional[T.Any] = None" for f in exclusive_field_names]
+    )
+    dict_fields_str = ", ".join([f'"{f}": {f}' for f in exclusive_field_names])
+    get_str = f"""
+async def get(self, given_client: AsyncIOClient = None, {params_fields_str}) -> T.Optional[{node_name}]:
+    return await super().get(given_client=given_client, **{{{dict_fields_str}}})
+    """
+    gerror_str = f"""
+async def gerror(self, given_client: AsyncIOClient = None, {params_fields_str}) -> {node_name}:
+    return await super().gerror(given_client=given_client, **{{{dict_fields_str}}})
+    """
+    return f"{get_str}\n{gerror_str}"
+
+
 def build_update_function_str(node_resolver_name: str, links: T.List[Link]) -> str:
     link_strs: T.List[str] = []
     link_names: T.List[str] = []
@@ -111,7 +127,7 @@ async def update(
 ) -> None:
     set_links_d = {{{", ".join([f'"{link_name}": {link_name}' for link_name in link_names])}}}
     set_links_d = {{key: val for key, val in set_links_d.items() if val is not None}}
-    
+
     return await super().update(
         given_resolver=given_resolver,
         error_if_no_update=error_if_no_update,
@@ -314,7 +330,14 @@ def {prop.name}(self) -> {prop.type_str}:
     # resolver
     resolver_properties_str = f"_node = {object_type.node_name}"
     resolver_link_functions_str = "\n".join(resolver_function_strs)
-    resolver_inner_strs = [resolver_properties_str, resolver_link_functions_str]
+    resolver_get_functions_str = build_get_functions_str(
+        node_name=object_type.node_name, exclusive_field_names=exclusive_fields
+    )
+    resolver_inner_strs = [
+        resolver_properties_str,
+        resolver_link_functions_str,
+        resolver_get_functions_str,
+    ]
     resolver_inner_str = "\n".join(resolver_inner_strs)
     resolver_s = f"class {node_resolver_name}(Resolver[{object_type.node_name}]):\n{indent_lines(resolver_inner_str)}"
 
